@@ -46,16 +46,6 @@
 #include "images/cdplayer-next.xpm"
 #include "images/cdplayer-eject.xpm"
 
-#if defined(sun) || defined(__sun__)
-#if defined(SVR4) || defined(__svr4__)
-#   define DEV_PATH "/vol/dev/aliases/cdrom0"
-#else
-#   define DEV_PATH "/dev/rcd0"
-#endif
-#else
-#   define DEV_PATH "/dev/cdrom"
-#endif
-
 #define TIMEOUT_VALUE 500
 
 /* Function prototypes */
@@ -101,7 +91,7 @@ static void make_applet_accessible(CDPlayerData *cd);
 /* Bonobo Verbs for our popup menu */
 static const BonoboUIVerb applet_menu_verbs [] = {
     BONOBO_UI_UNSAFE_VERB ("RunGTCD", start_gtcd_cb),
-    BONOBO_UI_UNSAFE_VERB ("Properties", properties_cb),
+    BONOBO_UI_UNSAFE_VERB ("Preferences", properties_cb),
     BONOBO_UI_UNSAFE_VERB ("Help", help_cb),
     BONOBO_UI_UNSAFE_VERB ("About", about_cb),
     BONOBO_UI_VERB_END
@@ -198,7 +188,7 @@ static void
 cdplayer_load_config(CDPlayerData *cd)
 {
     g_free(cd->devpath);
-    cd->devpath = panel_applet_gconf_get_string(PANEL_APPLET(cd->panel.applet), "device-path", NULL);
+    cd->devpath = panel_applet_gconf_get_string(PANEL_APPLET(cd->panel.applet), "device_path", NULL);
     if (!cd->devpath || !strcmp(cd->devpath, "none"))
     {
         g_free(cd->devpath);
@@ -209,7 +199,7 @@ cdplayer_load_config(CDPlayerData *cd)
 static void
 cdplayer_save_config(CDPlayerData *cd)
 {
-    panel_applet_gconf_set_string(PANEL_APPLET(cd->panel.applet), "device-path", cd->devpath, NULL);
+    panel_applet_gconf_set_string(PANEL_APPLET(cd->panel.applet), "device_path", cd->devpath, NULL);
 }
 
 static void
@@ -337,7 +327,7 @@ set_default_device (GtkButton *button, gpointer data)
     cdplayer_save_config(cd);  
 }
     
-
+/* FIXME: change the fn name later to reflect Preferences */
 static void
 properties_cb (GtkWidget *w, gpointer data)
 {
@@ -353,10 +343,11 @@ properties_cb (GtkWidget *w, gpointer data)
 
     cd = (CDPlayerData *) data;
 
-    dialog = gtk_dialog_new_with_buttons(_("CD Player Properties"),
+    dialog = gtk_dialog_new_with_buttons(_("CD Player Preferences"),
                                          NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
                                          GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
                                          NULL);
+    gtk_dialog_set_default_response(GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
     box = GTK_DIALOG(dialog)->vbox;
     
     hbox = gtk_hbox_new(FALSE, 0);
@@ -369,7 +360,7 @@ properties_cb (GtkWidget *w, gpointer data)
     gtk_widget_show(image);
     set_atk_name_description(image, _("Disc Image"), _("An image of a cd-rom disc"));
 
-    label = gtk_label_new(_("Device Path:"));
+    label = gtk_label_new_with_mnemonic(_("Device _Path:"));
     gtk_misc_set_padding (GTK_MISC (label), GNOME_PAD_SMALL, 0);
     gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
     gtk_widget_show(label);
@@ -569,7 +560,6 @@ control_button_factory(gchar * pixmap_data[], GCallback func, CDPlayerData * cd)
 
     w = gtk_button_new();
     GTK_WIDGET_UNSET_FLAGS(w, GTK_CAN_DEFAULT);
-    GTK_WIDGET_UNSET_FLAGS(w, GTK_CAN_FOCUS);
     pixbuf = gdk_pixbuf_new_from_xpm_data ((const char **)pixmap_data);
     image = gtk_image_new_from_pixbuf(pixbuf);
     if (pixbuf)
@@ -697,11 +687,13 @@ cd_panel_update(GtkWidget * cdplayer, CDPlayerData * cd)
     }
     if (description)
     {
-        cd->time_description = g_strdup_printf("Time elapsed is %d minutes and
-            %d seconds", stat.relative_address.minute,
-            stat.relative_address.second);
-        cd->track_description = g_strdup_printf("Current track number is %d",
-            stat.track);
+        cd->time_description =
+            g_strdup_printf("Time elapsed is %d minutes and %d seconds",
+                stat.relative_address.minute,
+                stat.relative_address.second);
+        cd->track_description =
+            g_strdup_printf("Current track number is %d",
+                stat.track);
         set_atk_name_description(cd->panel.time, _("Elapsed time"),
             cd->time_description);
         set_atk_name_description(cd->panel.track_control.display,
@@ -711,9 +703,9 @@ cd_panel_update(GtkWidget * cdplayer, CDPlayerData * cd)
     }
     else
     {
-        set_atk_name_description(cd->panel.time, _("Elapsed time"), _(""));
+        set_atk_name_description(cd->panel.time, _("Elapsed time"), "");
         set_atk_name_description(cd->panel.track_control.display,
-            _("Track number"), _(""));
+            _("Track number"), "");
     }
     return;
     cdplayer = NULL; 
@@ -863,13 +855,13 @@ set_atk_relation(GtkWidget *label, GtkWidget *widget)
     atk_widget = gtk_widget_get_accessible(widget);
     atk_label = gtk_widget_get_accessible(label);
 
+    /* Set the label-for relation */
+    gtk_label_set_mnemonic_widget(GTK_LABEL (label), widget);	
+
     /* Check if gail is loaded */
     if (GTK_IS_ACCESSIBLE (atk_widget) == FALSE)
         return;
 
-    /* Set the label-for relation */
-    gtk_label_set_mnemonic_widget(GTK_LABEL (label), widget);	
-
     /* Set the labelled-by relation */
     relation_set = atk_object_ref_relation_set(atk_widget);
     targets[0] = atk_label;
