@@ -48,6 +48,7 @@
 
 int NumLockMask, CapsLockMask, ScrollLockMask;
 
+gboolean gail_loaded = FALSE;
 GtkWidget *bah_window = NULL;
 
 gchar *
@@ -110,6 +111,7 @@ gkb_draw (GKB * gkb)
     }
 
   gtk_tooltips_set_tip (gkb->tooltips, gkb->applet, gkb->keymap->name, NULL);
+  add_atk_namedesc(gkb->applet, gkb->keymap->name, _("Press the hotkey to switch between layouts. The hotkey can be set through Properties dialog"));
 
 }
 
@@ -347,11 +349,11 @@ applet_save_session ()
   gchar str[100];
   int i = 0;
 
-  panel_applet_gconf_set_int (PANEL_APPLET (gkb->applet), "num", gkb->n, NULL);
-  panel_applet_gconf_set_bool (PANEL_APPLET (gkb->applet), "small", gkb->is_small, NULL);
-  panel_applet_gconf_set_string (PANEL_APPLET (gkb->applet), "key", gkb->key, NULL);
+  gconf_applet_set_int (PANEL_APPLET (gkb->applet), "num", gkb->n, NULL);
+  gconf_applet_set_bool (PANEL_APPLET (gkb->applet), "small", gkb->is_small, NULL);
+  gconf_applet_set_string (PANEL_APPLET (gkb->applet), "key", gkb->key, NULL);
   text = gkb_util_get_text_from_mode (gkb->mode);
-  panel_applet_gconf_set_string (PANEL_APPLET (gkb->applet), "mode", text, NULL);
+  gconf_applet_set_string (PANEL_APPLET (gkb->applet), "mode", text, NULL);
 
   while (list)
     {
@@ -359,17 +361,17 @@ applet_save_session ()
       if (actdata)
 	{
 	  g_snprintf (str, sizeof (str), "name_%d", i);
-	  panel_applet_gconf_set_string (PANEL_APPLET (gkb->applet), str, actdata->name, NULL);
+	  gconf_applet_set_string (PANEL_APPLET (gkb->applet), str, actdata->name, NULL);
 	  g_snprintf (str, sizeof (str), "country_%d", i);
-	  panel_applet_gconf_set_string (PANEL_APPLET (gkb->applet), str, actdata->country, NULL);
+	  gconf_applet_set_string (PANEL_APPLET (gkb->applet), str, actdata->country, NULL);
 	  g_snprintf (str, sizeof (str), "lang_%d", i);
-	  panel_applet_gconf_set_string (PANEL_APPLET (gkb->applet), str, actdata->lang, NULL);
+	  gconf_applet_set_string (PANEL_APPLET (gkb->applet), str, actdata->lang, NULL);
 	  g_snprintf (str, sizeof (str), "label_%d", i);
-	  panel_applet_gconf_set_string (PANEL_APPLET (gkb->applet), str, actdata->label, NULL);
+	  gconf_applet_set_string (PANEL_APPLET (gkb->applet), str, actdata->label, NULL);
 	  g_snprintf (str, sizeof (str), "flag_%d", i);
-	  panel_applet_gconf_set_string (PANEL_APPLET (gkb->applet), str, actdata->flag, NULL);
+	  gconf_applet_set_string (PANEL_APPLET (gkb->applet), str, actdata->flag, NULL);
 	  g_snprintf (str, sizeof (str), "command_%d", i);
-	  panel_applet_gconf_set_string (PANEL_APPLET (gkb->applet), str, actdata->command, NULL);
+	  gconf_applet_set_string (PANEL_APPLET (gkb->applet), str, actdata->command, NULL);
 	}
 
       list = list->next;
@@ -383,7 +385,7 @@ gkb_load_pref(const gchar * key, const gchar * defaultv)
 {
  gchar * value;
 
- value = panel_applet_gconf_get_string (PANEL_APPLET(gkb->applet), key, NULL);
+ value = gconf_applet_get_string (PANEL_APPLET(gkb->applet), key, NULL);
  
  if (value == NULL) {
   value = g_strdup (defaultv);
@@ -438,12 +440,12 @@ load_properties (GKB * gkb)
 
   gkb->maps = NULL;
 
-  gkb->n = panel_applet_gconf_get_int (PANEL_APPLET(gkb->applet), "num", NULL);
+  gkb->n = gconf_applet_get_int (PANEL_APPLET(gkb->applet), "num", NULL);
 
   gkb->key = gkb_load_pref ("key", "Mod1-Shift_L");
   convert_string_to_keysym_state (gkb->key, &gkb->keysym, &gkb->state);
 
-  gkb->is_small = panel_applet_gconf_get_bool (PANEL_APPLET(gkb->applet), "small", NULL);
+  gkb->is_small = gconf_applet_get_bool (PANEL_APPLET(gkb->applet), "small", NULL);
 #ifdef THIS_IS_UNNECESSARY
   if (gkb->is_small == NULL) {
     gkb->is_small = TRUE;
@@ -807,7 +809,10 @@ gkb_factory (PanelApplet *applet,
 		gpointer     data)
 {
  	gboolean retval = FALSE;
-
+	if ( GTK_IS_ACCESSIBLE(gtk_widget_get_accessible(GTK_WIDGET(applet))))
+	  {
+            gail_loaded = TRUE;
+          }
         if (!strcmp (iid, "OAFIID:GNOME_KeyboardApplet"))
 		retval = fill_gkb_applet (applet);
 
@@ -820,3 +825,37 @@ PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_KeyboardApplet_Factory",
                              "0",
                              gkb_factory,
                              NULL)
+
+/* Add AtkRelation */                                                           
+void                                                                            
+add_atk_relation(GtkWidget *obj1, GtkWidget *obj2, AtkRelationType rel_type)
+{
+    AtkObject *atk_obj1, *atk_obj2;
+    AtkRelationSet *relation_set;
+    AtkRelation *relation;
+
+    atk_obj1 = gtk_widget_get_accessible(obj1);
+
+    atk_obj2 = gtk_widget_get_accessible(obj2);
+
+    relation_set = atk_object_ref_relation_set (atk_obj1);
+    relation = atk_relation_new(&atk_obj2, 1, rel_type);
+    atk_relation_set_add(relation_set, relation);
+    g_object_unref(G_OBJECT (relation));
+}
+
+/* Accessible name and description */                                           
+void                                                                            
+add_atk_namedesc(GtkWidget *widget, const gchar *name, const gchar *desc)       
+{                                                                               
+    AtkObject *atk_widget;                                                      
+    atk_widget = gtk_widget_get_accessible(widget);                             
+    if (name)                                                                   
+    {                                                                           
+      atk_object_set_name(atk_widget, name);                                    
+    }                                                                           
+    if (desc)                                                                   
+    {                                                                           
+      atk_object_set_description(atk_widget, desc);                             
+    }                                                                           
+}                                                                               
