@@ -34,6 +34,7 @@
 #include <unistd.h>
 #include <dirent.h>
 #include <gdk/gdkx.h>
+#include "customdrawingarea.h"
 
 #define STOCK_QUOTE(sq) ((StockQuote *)(sq))
 
@@ -69,6 +70,7 @@
 	{
 		GtkWidget *applet;
 		GtkWidget *label;
+		GnomeVFSAsyncHandle *vfshandle;
 
 		GdkPixmap *pixmap;
 		GtkWidget * drawing_area;
@@ -111,6 +113,7 @@
 		gchar * new_font;
 		GdkFont * extra_font;
 		GdkFont * small_font;
+		GtkTooltips * tooltips;
 		gint symbolfont;
 		gint whichlabel;
 	} StockData;
@@ -144,6 +147,15 @@
         gint QuitFontDialog( GtkWidget *widget, void *data ) ;
 	/* end font funcs and vars */
 
+	/* accessibility funcs and vars */
+	GtkWidget *access_drawing_area;
+	StockData *access_stock;
+
+	static void setup_refchild_nchildren(GtkWidget * vbox);
+	static gint gtik_vbox_accessible_get_n_children(AtkObject *obj);
+	static AtkObject* gtik_vbox_accessible_ref_child(AtkObject *obj, gint i);
+	/* end accessibility funcs and vars */
+
 	/*-----------------------------------------------------------------*/
 	static void load_fonts(StockData *stockdata)
 	{
@@ -166,10 +178,6 @@
 		stockdata->small_font = gdk_font_from_description (font);
 		pango_font_description_free (font);
 
-		/* If fonts do not load */
-		if (!stockdata->my_font)
-			g_error("Could not load fonts!");
-
 		if ( !stockdata->extra_font || (stockdata->props.arrows == FALSE ) ){
 			
 			if (stockdata->extra_font)
@@ -186,10 +194,11 @@
 			stockdata->symbolfont = 1;
 
 		}
+		if (!stockdata->my_font) {
+			stockdata->my_font = gdk_font_load("fixed 12");
+		}
 		if (!stockdata->small_font) {
-			if (stockdata->small_font)
-				gdk_font_unref(stockdata->small_font);
-			stockdata->small_font = gdk_font_load("fixed");
+			stockdata->small_font = gdk_font_load("fixed 12");
 		}
 
 	}
@@ -200,7 +209,7 @@ static void xfer_callback (GnomeVFSAsyncHandle *handle, GnomeVFSXferProgressInfo
 	StockData *stockdata = data;
 
 	if (info->phase == GNOME_VFS_XFER_PHASE_COMPLETED) {
-
+		stockdata->vfshandle = NULL;
 		if (!configured(stockdata)) {
 			reSetOutputArray(stockdata);
 			fprintf(stderr, "No data!\n");
@@ -219,6 +228,9 @@ static gint updateOutput(gpointer data)
 	char *source_text_uri, *dest_text_uri;
 	GnomeVFSAsyncHandle *vfshandle;
 
+	if (stockdata->vfshandle != NULL)
+		return FALSE;
+		
 	source_text_uri = g_strconcat("http://finance.yahoo.com/q?s=",
 				      stockdata->props.tik_syms,
 				      "&d=v2",
@@ -234,7 +246,7 @@ static gint updateOutput(gpointer data)
 	g_free (dest_text_uri);
 
 	if (GNOME_VFS_OK !=
-	    gnome_vfs_async_xfer(&vfshandle, sources, dests,
+	    gnome_vfs_async_xfer(&stockdata->vfshandle, sources, dests,
 				 GNOME_VFS_XFER_DEFAULT,
 				 GNOME_VFS_XFER_ERROR_MODE_ABORT,
 				 GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,
@@ -245,6 +257,7 @@ static gint updateOutput(gpointer data)
 
 		info.phase = GNOME_VFS_XFER_PHASE_COMPLETED;
 		xfer_callback(NULL, &info, stockdata);
+		stockdata->vfshandle = NULL;
 	}
 
 	g_list_free(sources);
@@ -296,12 +309,12 @@ static gint updateOutput(gpointer data)
 								       "font",
 								       NULL);
 		if (!stockdata->props.font)
-			stockdata->props.font = g_strdup ("fixed");
+			stockdata->props.font = g_strdup ("fixed 12");
 		stockdata->props.font2 = panel_applet_gconf_get_string (applet,
 									"font2",
 									NULL);
 		if (!stockdata->props.font2)
-			stockdata->props.font2 = g_strdup ("-*-clean-medium-r-normal-*-*-100-*-*-c-*-iso8859-1");
+			stockdata->props.font2 = g_strdup ("fixed 12");
 		
 		stockdata->props.buttons = panel_applet_gconf_get_bool(applet,
 									  "buttons",
@@ -648,7 +661,8 @@ static gint updateOutput(gpointer data)
 		static const gchar *authors[] = {
 			"Jayson Lorenzen <jayson_lorenzen@yahoo.com>",
 			"Jim Garrison <garrison@users.sourceforge.net>",
-			"Rached Blili <striker@dread.net>"
+			"Rached Blili <striker@dread.net>",
+			NULL
 		};
 
 		about = gnome_about_new (_("The GNOME Stock Ticker"), VERSION,
@@ -735,7 +749,7 @@ static gint updateOutput(gpointer data)
 					    stockdata->props.timeout, NULL);
 		gtk_timeout_remove(stockdata->updateTimeID);
 		stockdata->updateTimeID = gtk_timeout_add(stockdata->props.timeout * 60000,
-				                         (gpointer)updateOutput,"NULL");
+				                         (gpointer)updateOutput, stockdata);
 		
 	}
 	
@@ -1102,6 +1116,7 @@ static gint updateOutput(gpointer data)
 
 		model = gtk_list_store_new (1, G_TYPE_STRING);
 		list = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
+		gtk_widget_set_size_request (list, 70, -1);
 		g_object_unref (G_OBJECT (model));
 		
 		/*selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree));
@@ -1134,7 +1149,7 @@ static gint updateOutput(gpointer data)
 		hbox = gtk_hbox_new(FALSE,5);
 		vbox = gtk_vbox_new(FALSE,5);
 
-		label = gtk_label_new(_("New Symbol:"));
+		label = gtk_label_new_with_mnemonic(_("_New Symbol:"));
 		gtk_box_pack_start(GTK_BOX(hbox),label,TRUE,TRUE,0);
 
 		entry = gtk_entry_new();
@@ -1143,6 +1158,7 @@ static gint updateOutput(gpointer data)
 		g_signal_connect (G_OBJECT (entry), "activate",
 				  G_CALLBACK (add_symbol), stockdata);
 		
+		set_relation(entry, GTK_LABEL(label));
 		
 		button = gtk_button_new_with_mnemonic(_("_Add"));
 		g_object_set_data (G_OBJECT (button), "entry", entry);
@@ -1203,7 +1219,7 @@ static gint updateOutput(gpointer data)
 		vbox = gtk_vbox_new (FALSE, 4);
 		gtk_container_set_border_width (GTK_CONTAINER (vbox), 8);
 		
-		button = gtk_check_button_new_with_label (_("Use HTTP proxy"));
+		button = gtk_check_button_new_with_mnemonic (_("_Use HTTP proxy"));
     		gtk_box_pack_start (GTK_BOX (vbox), button, 
     				    FALSE, FALSE, 0);
     		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), use_proxy);
@@ -1213,7 +1229,7 @@ static gint updateOutput(gpointer data)
     		hbox = gtk_hbox_new (FALSE, 2);
     		gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
     
-    		label = gtk_label_new (_("Location :"));
+    		label = gtk_label_new_with_mnemonic (_("_Location :"));
     		gtk_box_pack_start (GTK_BOX (hbox), label, 
     			    FALSE, FALSE, 0);
     
@@ -1224,10 +1240,12 @@ static gint updateOutput(gpointer data)
     		g_signal_connect (G_OBJECT (stockdata->proxy_url_entry), "focus_out_event",
     		          G_CALLBACK (proxy_url_changed), stockdata);
 
+    		set_relation (stockdata->proxy_url_entry, GTK_LABEL (label));
+
     		hbox = gtk_hbox_new (FALSE, 2);
     		gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
     
-    		label = gtk_label_new (_("Port :"));
+    		label = gtk_label_new_with_mnemonic (_("P_ort :"));
     		gtk_widget_show (label);
     		gtk_box_pack_start (GTK_BOX (hbox), label, 
     			    FALSE, FALSE, 0);
@@ -1237,8 +1255,9 @@ static gint updateOutput(gpointer data)
     				    FALSE, FALSE, 0);
     		g_signal_connect (G_OBJECT (stockdata->proxy_port_entry), "focus_out_event",
     		          G_CALLBACK (proxy_port_changed), stockdata);
-    
-    		stockdata->proxy_auth_button = gtk_check_button_new_with_label (_("Proxy requires a uername and password"));
+    		set_relation (stockdata->proxy_port_entry, GTK_LABEL (label));
+    		
+    		stockdata->proxy_auth_button = gtk_check_button_new_with_mnemonic (_("Pro_xy requires a uername and password"));
     		gtk_box_pack_start (GTK_BOX (vbox), stockdata->proxy_auth_button, 
     				    FALSE, FALSE, 0);
     		gtk_toggle_button_set_active 
@@ -1249,7 +1268,7 @@ static gint updateOutput(gpointer data)
     		hbox = gtk_hbox_new (FALSE, 2);
     		gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
     
-    		label = gtk_label_new (_("Username:"));
+    		label = gtk_label_new_with_mnemonic (_("Us_ername:"));
     		gtk_box_pack_start (GTK_BOX (hbox), label, 
     			    FALSE, FALSE, 0);
     
@@ -1259,10 +1278,12 @@ static gint updateOutput(gpointer data)
     		g_signal_connect (G_OBJECT (stockdata->proxy_user_entry), "focus_out_event",
     		          G_CALLBACK (proxy_user_changed), stockdata);
 
+    		set_relation (stockdata->proxy_user_entry, GTK_LABEL (label));
+
     		hbox = gtk_hbox_new (FALSE, 2);
     		gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
     
-    		label = gtk_label_new (_("Password:"));
+    		label = gtk_label_new_with_mnemonic (_("Pass_word:"));
     		gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
     		stockdata->proxy_passwd_entry = gtk_entry_new ();
@@ -1272,6 +1293,8 @@ static gint updateOutput(gpointer data)
     		g_signal_connect (G_OBJECT (stockdata->proxy_passwd_entry), 
     			          "focus_out_event",
     		                  G_CALLBACK (proxy_password_changed), stockdata);
+
+    		set_relation (stockdata->proxy_passwd_entry, GTK_LABEL (label));
     		 	
     		gtk_entry_set_text(GTK_ENTRY(stockdata->proxy_url_entry), 
     		       proxy_url ? 
@@ -1331,7 +1354,7 @@ static gint updateOutput(gpointer data)
 			return;
 		}
 
-		stockdata->pb = gtk_dialog_new_with_buttons (_("Stock Ticker Properties"), 
+		stockdata->pb = gtk_dialog_new_with_buttons (_("Stock Ticker Preferences"), 
 							     NULL,
 						  	     GTK_DIALOG_DESTROY_WITH_PARENT,
 						             GTK_STOCK_CLOSE, 
@@ -1352,12 +1375,14 @@ static gint updateOutput(gpointer data)
 		gtk_container_set_border_width(GTK_CONTAINER(vbox), GNOME_PAD);
 		gtk_container_set_border_width(GTK_CONTAINER(vbox2), GNOME_PAD);
 
-		timeout_label = gtk_label_new(_("Update Frequency in minutes:"));
-		timeout_a = gtk_adjustment_new( stockdata->props.timeout, 0.5, 128, 
+		timeout_label = gtk_label_new_with_mnemonic(_("Update Fre_quency in minutes:"));
+		timeout_a = gtk_adjustment_new( stockdata->props.timeout, 1, 128, 
 					       1, 8, 8 );
 		timeout_c  = gtk_spin_button_new( GTK_ADJUSTMENT(timeout_a), 1, 0 );
 		gtk_widget_set_usize(timeout_c,60,-1);
 
+		set_relation(timeout_c, GTK_LABEL(timeout_label));
+
 		gtk_box_pack_start_defaults( GTK_BOX(panel2), timeout_label );
 		gtk_box_pack_start_defaults( GTK_BOX(panel2), timeout_c );
 		gtk_box_pack_start(GTK_BOX(vbox), panel2, FALSE,
@@ -1378,16 +1403,16 @@ static gint updateOutput(gpointer data)
 					  "changed",GTK_SIGNAL_FUNC(changed_cb),
 					  GTK_OBJECT(stockdata->pb));
 
-		check = gtk_check_button_new_with_label(_("Display only symbols and price"));
+		check = gtk_check_button_new_with_mnemonic(_("Displa_y only symbols and price"));
 		g_signal_connect (G_OBJECT (check), "toggled",
 				  G_CALLBACK (output_toggled), stockdata);
-		check2 = gtk_check_button_new_with_label(_("Scroll left to right"));
+		check2 = gtk_check_button_new_with_mnemonic(_("Scroll _left to right"));
 		g_signal_connect (G_OBJECT (check2), "toggled",
 				  G_CALLBACK (rtl_toggled), stockdata);
-		check3 = gtk_check_button_new_with_label(_("Display arrows instead of -/+"));
+		check3 = gtk_check_button_new_with_mnemonic(_("Display a_rrows instead of -/+"));
 		g_signal_connect (G_OBJECT (check3), "toggled",
 				  G_CALLBACK (arrows_toggled), stockdata);
-		check4 = gtk_check_button_new_with_label(_("Enable scroll buttons"));
+		check4 = gtk_check_button_new_with_mnemonic(_("_Enable scroll buttons"));
 		g_signal_connect (G_OBJECT (check4), "toggled",
 				  G_CALLBACK (scroll_toggled), stockdata);
 
@@ -1413,8 +1438,10 @@ static gint updateOutput(gpointer data)
 							TRUE);
 
 		/* COLOR */
-		upLabel = gtk_label_new(_("+ Color"));
+		upLabel = gtk_label_new_with_mnemonic(_("+ C_olor"));
 		upColor = gnome_color_picker_new();
+		
+		set_relation(upColor, GTK_LABEL(upLabel));
 	
 		sscanf( stockdata->props.ucolor, "#%02x%02x%02x", &ur,&ug,&ub );
 	
@@ -1430,8 +1457,10 @@ static gint updateOutput(gpointer data)
 		gtk_box_pack_start_defaults( GTK_BOX(hbox3), upColor );
 		gtk_box_pack_start_defaults(GTK_BOX(vbox3),hbox3);
 
-		downLabel = gtk_label_new(_("- Color"));
+		downLabel = gtk_label_new_with_mnemonic(_("- Colo_r"));
 		downColor = gnome_color_picker_new();
+		
+		set_relation(downColor, GTK_LABEL(downLabel));
 
 		sscanf( stockdata->props.dcolor, "#%02x%02x%02x", &dr,&dg,&db );
 
@@ -1450,7 +1479,7 @@ static gint updateOutput(gpointer data)
                 /* For FONTS */
 		vbox3 = gtk_vbox_new(FALSE, 5); 
 		hbox3 = gtk_hbox_new(FALSE, 5);
-		label5 = gtk_label_new(_("Stock Symbol:"));
+		label5 = gtk_label_new_with_mnemonic(_("Stock Sy_mbol:"));
 
 		font_picker = gnome_font_picker_new ();
 		gnome_font_picker_set_font_name (GNOME_FONT_PICKER (font_picker),
@@ -1460,9 +1489,11 @@ static gint updateOutput(gpointer data)
                 gtk_box_pack_start_defaults(GTK_BOX(vbox3),hbox3);
                 g_signal_connect (G_OBJECT (font_picker), "font_set",
                 		  G_CALLBACK (font_cb), stockdata);
+
+		set_relation(font_picker, GTK_LABEL(label5));
                                 
 		hbox3 = gtk_hbox_new(FALSE, 5);
-		label5 = gtk_label_new(_("Stock Change:"));
+		label5 = gtk_label_new_with_mnemonic(_("Stock C_hange:"));
                 font_picker = gnome_font_picker_new ();
                 gnome_font_picker_set_font_name (GNOME_FONT_PICKER (font_picker),
 						 stockdata->props.font2);
@@ -1472,6 +1503,8 @@ static gint updateOutput(gpointer data)
                 g_signal_connect (G_OBJECT(font_picker),"font_set",
                                   G_CALLBACK(font2_cb),stockdata);
                 
+		set_relation(font_picker, GTK_LABEL(label5));
+
 		gtk_box_pack_start_defaults(GTK_BOX(panela),vbox3);
 
 
@@ -1519,9 +1552,10 @@ static gint updateOutput(gpointer data)
 		
 		panel_applet_add_preferences (applet, "/schemas/apps/gtik/prefs", NULL);
 		
-		stockdata = g_new0 (StockData, 1);
+		access_stock = stockdata = g_new0 (StockData, 1);
 		stockdata->applet = GTK_WIDGET (applet);
 		stockdata->timeout = 0;
+		stockdata->vfshandle = NULL;
 		stockdata->configFileName = g_strconcat (g_getenv ("HOME"), 
 						         "/.gtik.conf", NULL);
 
@@ -1537,12 +1571,14 @@ static gint updateOutput(gpointer data)
 					"clicked",
 					GTK_SIGNAL_FUNC(zipRight),stockdata);
 
+		stockdata->tooltips = gtk_tooltips_new ();
+		gtk_tooltips_set_tip(stockdata->tooltips, stockdata->leftButton, _("Skip forward"), "");
+		gtk_tooltips_set_tip(stockdata->tooltips, stockdata->rightButton, _("Skip backword"), "");
 
 		frame = gtk_frame_new(NULL);
 		gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
 
-
-		stockdata->drawing_area = gtk_drawing_area_new();
+		access_drawing_area = stockdata->drawing_area = GTK_WIDGET (custom_drawing_area_new());
 		gtk_drawing_area_size(GTK_DRAWING_AREA (stockdata->drawing_area),200,20);
 
 		gtk_widget_show(stockdata->drawing_area);
@@ -1596,6 +1632,8 @@ static gint updateOutput(gpointer data)
 			gtk_widget_show(stockdata->rightButton);
 		}
 
+		setup_refchild_nchildren(vbox);
+
 		updateOutput(stockdata);
 
 		return TRUE;
@@ -1608,6 +1646,8 @@ static gint updateOutput(gpointer data)
 	{
 		gboolean retval = FALSE;
     
+		setup_factory();
+    
 		if (!strcmp (iid, "OAFIID:GNOME_GtikApplet"))
 			retval = gtik_applet_fill (applet); 
     
@@ -1628,6 +1668,9 @@ static gint updateOutput(gpointer data)
 	/*-----------------------------------------------------------------*/
 	static void destroy_applet(GtkWidget *widget, gpointer data) {
 		StockData *stockdata = data;
+
+		g_object_unref (G_OBJECT (stockdata->tooltips));
+
 		if (stockdata->drawTimeID > 0) { 
 			gtk_timeout_remove(stockdata->drawTimeID); }
 		if (stockdata->updateTimeID >0) { 
@@ -1767,10 +1810,13 @@ static gint updateOutput(gpointer data)
 			   guint a, gpointer data) {
 		StockData *stockdata = data;
 		PanelApplet *applet = PANEL_APPLET (stockdata->applet);
+		guint8 red, gr, bl;
 		
 		if (stockdata->props.ucolor)
 			g_free (stockdata->props.ucolor);
-		stockdata->props.ucolor = g_strdup_printf ("#%02x%02x%02x", r, g, b );
+		
+		gnome_color_picker_get_i8 (GNOME_COLOR_PICKER(cp), &red, &gr, &bl, NULL);
+		stockdata->props.ucolor = g_strdup_printf("#%06X", (red << 16) + (gr << 8) + bl);
 		panel_applet_gconf_set_string (applet, "ucolor", 
 					       stockdata->props.ucolor, NULL);
 		
@@ -1783,10 +1829,12 @@ static gint updateOutput(gpointer data)
 			   guint a, gpointer data) {
 		StockData *stockdata = data;
 		PanelApplet *applet = PANEL_APPLET (stockdata->applet);
+		guint8 red, gr, bl;
 		
 		if (stockdata->props.dcolor)
 			g_free (stockdata->props.dcolor);
-		stockdata->props.dcolor = g_strdup_printf ("#%02x%02x%02x", r, g, b );
+		gnome_color_picker_get_i8 (GNOME_COLOR_PICKER(cp), &red, &gr, &bl, NULL);
+		stockdata->props.dcolor = g_strdup_printf("#%06X", (red << 16) + (gr << 8) + bl);
 		panel_applet_gconf_set_string (applet, "dcolor", 
 					       stockdata->props.dcolor, NULL);
 		
@@ -1837,5 +1885,47 @@ static gint updateOutput(gpointer data)
 		g_free (buff);
 	}
 
+	static void setup_refchild_nchildren(GtkWidget * vbox){
+		AtkObject *atk_vbox;
+		AtkObjectClass *atk_vbox_class;
 
+		atk_vbox = gtk_widget_get_accessible(vbox);
+		atk_vbox_class = ATK_OBJECT_GET_CLASS(atk_vbox);
+		atk_vbox_class->get_n_children = gtik_vbox_accessible_get_n_children;
+		atk_vbox_class->ref_child = gtik_vbox_accessible_ref_child;
+	}
 
+	static gint gtik_vbox_accessible_get_n_children(AtkObject *obj){
+		return 1;
+	}
+
+	static AtkObject* gtik_vbox_accessible_ref_child(AtkObject *obj, gint i){
+		return (gtk_widget_get_accessible(access_drawing_area));
+	}
+
+	gchar* gtik_get_text(void) {
+		GArray *quotes = access_stock->quotes;
+		gchar **strs = NULL;
+		gchar *buff;
+		gint i;
+
+		strs = g_new0 (gchar*, access_stock->setCounter + 1);
+		g_return_if_fail (strs != NULL);
+
+		for(i=0;i<access_stock->setCounter;i++) {
+			if (access_stock->props.output == FALSE) {
+				strs[i] = g_strdup_printf ("%s  %s",
+					STOCK_QUOTE (quotes->data)[i].price,
+					STOCK_QUOTE (quotes->data)[i].change);
+			}
+			else {
+				strs[i] = g_strdup_printf ("%s",
+					STOCK_QUOTE (quotes->data)[i].price);
+			}
+		}
+		buff = g_strjoinv ("  ", strs);
+
+		g_strfreev (strs);
+
+		return buff;
+	}
