@@ -23,14 +23,15 @@
 #include "help.h"
 
 void 
-show_help(AppletWidget *applet, gpointer data)
+show_help(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 {
-    static GnomeHelpMenuEntry help_entry = { NULL, "index.html"};
-
-    help_entry.name = gnome_app_id;
+    GError *error = NULL;
     
-    gnome_help_display(NULL, &help_entry);
+    gnome_help_display_desktop (NULL, "command-line", "command-line", NULL, &error);
+    if (error) {
+    	g_warning ("help error: %s\n", error->message);
+	g_error_free (error);
+    }
+
     return;
-    applet = NULL;
-    data = NULL;
 }
