@@ -51,8 +51,7 @@ void
 properties_close_cb(GtkWidget *widget, gint arg, gpointer data)
 {
 	
-	if (arg == GTK_RESPONSE_CLOSE)
-		gtk_widget_destroy(widget);
+	gtk_widget_destroy(widget);
 	
 	return;
 }
@@ -77,50 +76,16 @@ property_toggled_cb(GtkWidget *widget, gpointer name)
 	if (active)
 	{
 		for (i = 0; i < 5; i++)
-			gtk_widget_set_sensitive(ma->check_boxes[i], TRUE);
-		
-		switch(prop_type)
-		{
-			case PROP_CPU:
-			{
-				ma->graphs[prop_type] = cpuload_applet_new(ma->applet, NULL);
-				break;
-			}
-			case PROP_MEM:
-			{
-				ma->graphs[prop_type] = memload_applet_new(ma->applet, NULL);
-				break;
-			}
-			case PROP_NET:
-			{
-				ma->graphs[prop_type] = netload_applet_new(ma->applet, NULL);
-				break;
-			}
-			case PROP_SWAP:
-			{
-				ma->graphs[prop_type] = swapload_applet_new(ma->applet, NULL);
-				break;
-			}
-			case PROP_AVG:
-			{
-				ma->graphs[prop_type] = loadavg_applet_new(ma->applet, NULL);
-				break;
-			}
-			default:
-				g_assert_not_reached();
-		}
-		
-		gtk_box_pack_start(GTK_BOX(ma->box), ma->graphs[prop_type]->main_widget, FALSE, FALSE, 1);
-		gtk_widget_show_all(ma->box);
+			gtk_widget_set_sensitive(ma->check_boxes[i], TRUE);	
+		gtk_widget_show_all (ma->graphs[prop_type]->main_widget);
+		ma->graphs[prop_type]->visible = TRUE;
 		load_graph_start(ma->graphs[prop_type]);
 	}
 	else
 	{
 		load_graph_stop(ma->graphs[prop_type]);
-		gtk_widget_destroy(ma->graphs[prop_type]->main_widget);
-		load_graph_unalloc(ma->graphs[prop_type]);
-		ma->graphs[prop_type]->visible = FALSE;;
-		
+		gtk_widget_hide (ma->graphs[prop_type]->main_widget);
+		ma->graphs[prop_type]->visible = FALSE;
 		properties_set_insensitive(ma);
 	}
 	
@@ -150,12 +115,10 @@ spin_button_changed_cb(GtkWidget *widget, gpointer name)
 		{
 			for (i = 0; i < 5; i++)
 			{
-				if (!ma->graphs[i]->visible)
-					continue;
-					
 				load_graph_stop(ma->graphs[i]);
 				ma->graphs[i]->speed = value;
-				load_graph_start(ma->graphs[i]);
+				if (ma->graphs[i]->visible)
+					load_graph_start(ma->graphs[i]);
 			}
 			
 			break;
@@ -164,16 +127,18 @@ spin_button_changed_cb(GtkWidget *widget, gpointer name)
 		{
 			for (i = 0; i < 5; i++)
 			{
-				if (!ma->graphs[i]->visible)
-					continue;
-				
-				/* the panel includes a 1 pixel border and the frame is 1 pixel wide */
-				ma->graphs[i]->size = value - 4;
+				ma->graphs[i]->size = value ;
 				
 				if (ma->graphs[i]->orient)
-					gtk_widget_set_size_request (ma->graphs[i]->main_widget, ma->graphs[i]->pixel_size, ma->graphs[i]->size);
+					gtk_widget_set_size_request (
+						ma->graphs[i]->main_widget, 
+						ma->graphs[i]->pixel_size, 
+						ma->graphs[i]->size);
 			    else
-					gtk_widget_set_size_request (ma->graphs[i]->main_widget, ma->graphs[i]->size, ma->graphs[i]->pixel_size);
+					gtk_widget_set_size_request (
+						ma->graphs[i]->main_widget, 
+						ma->graphs[i]->size, 
+						ma->graphs[i]->pixel_size);
 			}
 			
 			break;
@@ -193,7 +158,7 @@ add_page(GtkWidget *notebook, gchar *label)
 	GtkWidget *page_label;
 	
 	page = gtk_hbox_new(TRUE, 0);
-	page_label = gtk_label_new(label);
+	page_label = gtk_label_new_with_mnemonic(label);
 	gtk_container_set_border_width(GTK_CONTAINER(page), 3);
 		
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), page, page_label);
@@ -256,9 +221,10 @@ add_color_selector(GtkWidget *page, gchar *name, gchar *gconf_path, MultiloadApp
 		
 	object = gtk_label_new("I will never be seen"); /* this is used instead of a structure */
 	vbox = gtk_vbox_new(FALSE, 0);
-	label = gtk_label_new(name);
+	label = gtk_label_new_with_mnemonic(name);
 	color_picker = gnome_color_picker_new();
-	
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), color_picker);
+		
 	gtk_box_pack_start(GTK_BOX(vbox), color_picker, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 2);
 	
@@ -355,13 +321,14 @@ fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 	
 	orient = panel_applet_get_orient(ma->applet);
 	if ( (orient == PANEL_APPLET_ORIENT_UP) || (orient == PANEL_APPLET_ORIENT_DOWN) )
-		label_text = g_strdup(_("System monitor width: "));
+		label_text = g_strdup(_("System m_onitor width: "));
 	else
-		label_text = g_strdup(_("System monitor height: "));
+		label_text = g_strdup(_("System m_onitor height: "));
 	
-	label = gtk_label_new(label_text);
+	label = gtk_label_new_with_mnemonic(label_text);
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 3);
-	spin_button = gtk_spin_button_new_with_range(0, 1000, 5);
+	spin_button = gtk_spin_button_new_with_range(10, 1000, 5);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), spin_button);
 	g_object_set_data(G_OBJECT(spin_button), "user_data", ma);
 	g_object_set_data(G_OBJECT(spin_button), "prop_type",
 				GINT_TO_POINTER(PROP_SIZE));
@@ -376,9 +343,10 @@ fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 	hbox = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 1);
 	
-	label = gtk_label_new(_("System monitor speed: "));
+	label = gtk_label_new_with_mnemonic(_("Sys_tem monitor update interval: "));
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 3);
-	spin_button = gtk_spin_button_new_with_range(0, 9999, 10);
+	spin_button = gtk_spin_button_new_with_range(50, 10000, 50);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), spin_button);
 	g_object_set_data(G_OBJECT(spin_button), "user_data", ma);
 	g_object_set_data(G_OBJECT(spin_button), "prop_type",
 				GINT_TO_POINTER(PROP_SPEED));
@@ -397,31 +365,30 @@ fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), frame, FALSE, FALSE, 0);
 	
 	notebook = gtk_notebook_new();
-	gtk_notebook_set_homogeneous_tabs(GTK_NOTEBOOK(notebook), TRUE);
 	gtk_container_set_border_width(GTK_CONTAINER(notebook), 5);
 	gtk_container_add(GTK_CONTAINER(frame), notebook);
 	
-	page = add_page(notebook,  _("Processor"));
-	add_color_selector(page, _("User"), "cpuload_color0", ma);
-	add_color_selector(page, _("System"), "cpuload_color1", ma);
-	add_color_selector(page, _("Nice"), "cpuload_color2", ma);
-	add_color_selector(page, _("Idle"), "cpuload_color3", ma);
+	page = add_page(notebook,  _("P_rocessor"));
+	add_color_selector(page, _("_User"), "cpuload_color0", ma);
+	add_color_selector(page, _("S_ystem"), "cpuload_color1", ma);
+	add_color_selector(page, _("N_ice"), "cpuload_color2", ma);
+	add_color_selector(page, _("I_dle"), "cpuload_color3", ma);
 	
-	page = add_page(notebook,  _("Memory"));
-	add_color_selector(page, _("Other"), "memload_color0", ma);
-	add_color_selector(page, _("Shared"), "memload_color1", ma);
-	add_color_selector(page, _("Buffers"), "memload_color2", ma);
-	add_color_selector(page, _("Free"), "memload_color3", ma);
+	page = add_page(notebook,  _("M_emory"));
+	add_color_selector(page, _("Ot_her"), "memload_color0", ma);
+	add_color_selector(page, _("Sh_ared"), "memload_color1", ma);
+	add_color_selector(page, _("_Buffers"), "memload_color2", ma);
+	add_color_selector(page, _("F_ree"), "memload_color3", ma);
 	
-	page = add_page(notebook,  _("Network"));
-	add_color_selector(page, _("SLIP"), "netload_color0", ma);
-	add_color_selector(page, _("PLIP"), "netload_color1", ma);
-	add_color_selector(page, _("Ethernet"), "netload_color2", ma);
-	add_color_selector(page, _("Other"), "netload_color3", ma);
+	page = add_page(notebook,  _("Net_work"));
+	add_color_selector(page, _("S_LIP"), "netload_color0", ma);
+	add_color_selector(page, _("PL_IP"), "netload_color1", ma);
+	add_color_selector(page, _("Et_hernet"), "netload_color2", ma);
+	add_color_selector(page, _("_Other"), "netload_color3", ma);
 	
-	page = add_page(notebook,  _("Swap File"));
-	add_color_selector(page, _("Used"), "swapload_color0", ma);
-	add_color_selector(page, _("Free"), "swapload_color1", ma);
+	page = add_page(notebook,  _("Swap _File"));
+	add_color_selector(page, _("_Used"), "swapload_color0", ma);
+	add_color_selector(page, _("_Free"), "swapload_color1", ma);
 	
 	return;
 }
@@ -435,21 +402,20 @@ multiload_properties_cb(BonoboUIComponent *uic, gpointer data, const gchar *name
 	
 	if (dialog != NULL)
 	{
-	    gdk_window_show(dialog->window);
-	    gdk_window_raise(dialog->window);
+	    gtk_window_present (GTK_WINDOW (dialog));
 	    return;
 	}
 	
 	ma = (MultiloadApplet *)data;
 	
-	dialog = gtk_dialog_new_with_buttons(_("System Monitor Properties"), NULL, 0, GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
+	dialog = gtk_dialog_new_with_buttons(_("System Monitor Preferences"), NULL, 0, GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
 				
 	fill_properties(dialog, ma);
 
 	properties_set_insensitive(ma);
-				
+	
 	g_signal_connect (G_OBJECT(dialog), "destroy",
-			G_CALLBACK(gtk_widget_destroyed), &dialog);
+			  G_CALLBACK(gtk_widget_destroyed), &dialog);			
 	g_signal_connect(G_OBJECT(dialog), "response",
 			G_CALLBACK(properties_close_cb), NULL);
 			
